@@ -1,6 +1,6 @@
 package UV;
 
-our $VERSION = '1.912';
+our $VERSION = '2.000';
 our $XS_VERSION = $VERSION;
 
 use strict;
@@ -101,8 +101,6 @@ sub udp {
 
 1;
 
-__END__
-
 =encoding utf8
 
 =head1 NAME
@@ -166,8 +164,9 @@ Returns a new L<UV::Check> Handle object.
     # will also return the default loop
     my $loop = UV::Loop->new(1);
 
-Returns the default loop (which is a singleton object). This module already
-creates the default loop and you get access to it with this method.
+Returns the default loop as a L<UV::Loop> instance (which is a singleton
+object). This module already creates the default loop and you get access to it
+with this method.
 
 =head2 err_name
 
@@ -209,8 +208,9 @@ Returns a new L<UV::Idle> Handle object.
     my $loop = UV::Loop->default_loop();
     my $loop = UV::Loop->default();
 
-Returns the default loop (which is a singleton object). This module already
-creates the default loop and you get access to it with this method.
+Returns the default loop as a L<UV::Loop> instance (which is a singleton
+object). This module already creates the default loop and you get access to it
+with this method.
 
 =head2 poll
 
@@ -653,6 +653,35 @@ Unknown error
 
 =cut
 
+=head1 TODO
+
+The following features of L<libuv> are not currently wrapped by this module,
+but may be possible in some future version:
+
+=over 4
+
+=item *
+
+Filesystem requests listed in L<http://docs.libuv.org/en/v1.x/fs.html>.
+
+=item *
+
+Thread pools listed in L<http://docs.libuv.org/en/v1.x/threadpool.html>.
+
+=item *
+
+Many of the misc utilities listed in
+L<http://docs.libuv.org/en/v1.x/misc.html>.
+
+=item *
+
+L<UV::Process> stdio stream arguments given at
+L<http://docs.libuv.org/en/v1.x/process.html#c.uv_stdio_flags>.
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
